@@ -81,7 +81,7 @@ CglMixedIntegerRounding2::generateCuts(const OsiSolverInterface& si,
   //const CoinPackedMatrix & matrixByCol = *si.getMatrixByCol();
   const double* coefByCol  = matrixByCol.getElements();
   const int* rowInds       = matrixByCol.getIndices();
-  const int* colStarts     = matrixByCol.getVectorStarts();
+  const CoinBigIndex* colStarts     = matrixByCol.getVectorStarts();
 
 
   generateMirCuts(si, xlp, colUpperBound, colLowerBound,
@@ -332,7 +332,7 @@ mixIntRoundPreprocess(const OsiSolverInterface& si)
   numCols_ = si.getNumCols();
   const double* coefByRow  = matrixByRow.getElements();
   const int* colInds       = matrixByRow.getIndices();
-  const int* rowStarts     = matrixByRow.getVectorStarts();
+  const CoinBigIndex* rowStarts     = matrixByRow.getVectorStarts();
   const int* rowLengths    = matrixByRow.getVectorLengths();
   // Get copies of sense and RHS so we can modify if ranges
   if (sense_) {
@@ -502,12 +502,12 @@ mixIntRoundPreprocess(const OsiSolverInterface& si)
 	      (rowType == ROW_VARLB) || 
 	      (rowType == ROW_VAREQ) )  { 
       
-      int startPos = rowStarts[iRow];
-      int stopPos  = startPos + rowLengths[iRow];
+      CoinBigIndex startPos = rowStarts[iRow];
+      CoinBigIndex stopPos  = startPos + rowLengths[iRow];
       int    xInd = 0,  yInd = 0;   // x is continuous, y is integer
       double xCoef = 0.0, yCoef = 0.0;
 
-      for (int i = startPos; i < stopPos; ++i) {
+      for (CoinBigIndex i = startPos; i < stopPos; ++i) {
 	if ( fabs(coefByRow[i]) > EPSILON_ ) {
 	  if( integerType_[colInds[i]] ) {
 	    yInd  = colInds[i];
@@ -555,9 +555,9 @@ mixIntRoundPreprocess(const OsiSolverInterface& si)
   countC = 0;
   for (int i = 0; i < numRowCont_; ++i) {
     int indRow = indRowCont_[i];
-    int jStart = rowStarts[indRow];
-    int jStop = jStart + rowLengths[indRow];
-    for (int j = jStart; j < jStop; ++j) {
+    CoinBigIndex jStart = rowStarts[indRow];
+    CoinBigIndex jStop = jStart + rowLengths[indRow];
+    for (CoinBigIndex j = jStart; j < jStop; ++j) {
       int indCol = colInds[j];
       CglMixIntRoundVLB2 VLB = vlbs_[indCol];
       CglMixIntRoundVUB2 VUB = vubs_[indCol];
@@ -682,7 +682,7 @@ CglMixedIntegerRounding2::generateMirCuts(
 			    //const CoinPackedMatrix& matrixByCol,
 			    const double* coefByCol,
 			    const int* rowInds,
-			    const int* colStarts,
+			    const CoinBigIndex* colStarts,
 			    OsiCuts& cs ) const
 {
 
@@ -939,7 +939,7 @@ CglMixedIntegerRounding2::selectRowToAggregate(
 			    const double* colLowerBound,
 			    const CoinIndexedVector& setRowsAggregated,
 			    const double* xlp, const double* coefByCol,
-			    const int* rowInds, const int* colStarts,
+			    const int* rowInds, const CoinBigIndex* colStarts,
 			    int& rowSelected,
 			    int& colSelected ) const
 {
@@ -977,14 +977,14 @@ CglMixedIntegerRounding2::selectRowToAggregate(
     // In case this variable is acceptable look for possible rows
     if (delta > deltaMax) {
 
-      int iStart = colStarts[indCol];
-      int iStop  = colStarts[indCol+1];
+      CoinBigIndex iStart = colStarts[indCol];
+      CoinBigIndex iStop  = colStarts[indCol+1];
       //      int count = 0;
 
       //      std::vector<int> rowPossible;
 
       // find a row to use in aggregation
-      for (int i = iStart; i < iStop; ++i) {
+      for (CoinBigIndex i = iStart; i < iStop; ++i) {
 	int rowInd = rowInds[i];
 	if (!setRowsAggregated.denseVector()[rowInd]) {
 	  // if the row was not already selected, select it
@@ -1792,7 +1792,7 @@ CglMixedIntegerRounding2::generateCpp( FILE * fp)
   if (CRITERION_!=other.CRITERION_)
   fprintf(fp,"3  mixedIntegerRounding2.setCRITERION_(%d);\n",CRITERION_);
   if (doPreproc_!=other.doPreproc_)
-    fprintf(fp,"3  mixedIntegerRounding2.setDoPreproc_(%d);\n", doPreproc_);
+    fprintf(fp,"3  mixedIntegerRounding2.setDoPreproc(%d);\n", doPreproc_);
   if (getAggressiveness()!=other.getAggressiveness())
     fprintf(fp,"3  mixedIntegerRounding2.setAggressiveness(%d);\n",getAggressiveness());
   else
